'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRedux = require('react-redux');

var _Card = require('material-ui/Card');

var _IconButton = require('material-ui/IconButton');

var _IconButton2 = _interopRequireDefault(_IconButton);

var _close = require('material-ui/svg-icons/navigation/close');

var _close2 = _interopRequireDefault(_close);

var _reactIntl = require('react-intl');

var _features_by_id = require('../selectors/features_by_id');

var _features_by_id2 = _interopRequireDefault(_features_by_id);

var _field_mapping = require('../selectors/field_mapping');

var _field_mapping2 = _interopRequireDefault(_field_mapping);

var _color_index = require('../selectors/color_index');

var _color_index2 = _interopRequireDefault(_color_index);

var _visible_fields = require('../selectors/visible_fields');

var _visible_fields2 = _interopRequireDefault(_visible_fields);

var _field_analysis = require('../selectors/field_analysis');

var _field_analysis2 = _interopRequireDefault(_field_analysis);

var _intl_helpers = require('../util/intl_helpers');

var _marker_icon = require('./marker_icon');

var _marker_icon2 = _interopRequireDefault(_marker_icon);

var _image = require('./image');

var _image2 = _interopRequireDefault(_image);

var _feature_table = require('./feature_table');

var _feature_table2 = _interopRequireDefault(_feature_table);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
  card: {
    overflow: 'auto',
    width: '100%'
  },
  cardUnrestricted: {
    width: '100%'
  },
  header: {
    lineHeight: '22px',
    boxSizing: 'content-box',
    borderBottom: '1px solid #cccccc'
  },
  markerIcon: {
    width: 40,
    height: 40,
    margin: 0,
    marginRight: 16
  },
  media: {
    position: 'relative',
    height: '100%',
    padding: '67% 0 0 0'
  },
  img: {
    width: '100%',
    height: '100%',
    top: 0,
    left: 0,
    position: 'absolute',
    objectFit: 'cover'
  }
};

var FeatureDetail = function FeatureDetail(_ref) {
  var color = _ref.color,
      label = _ref.label,
      media = _ref.media,
      data = _ref.data,
      title = _ref.title,
      subtitle = _ref.subtitle,
      onCloseClick = _ref.onCloseClick,
      print = _ref.print;
  return _react2.default.createElement(
    _Card.Card,
    {
      className: 'card',
      style: styles.card,
      zDepth: 0 },
    _react2.default.createElement(
      _Card.CardHeader,
      {
        style: styles.header,
        avatar: _react2.default.createElement(_marker_icon2.default, { color: color, style: styles.markerIcon, label: label }),
        title: _react2.default.createElement(_reactIntl.FormattedMessage, (0, _intl_helpers.createMessage)('field_value')(title)),
        subtitle: _react2.default.createElement(_reactIntl.FormattedMessage, (0, _intl_helpers.createMessage)('field_value')(subtitle)) },
      onCloseClick && _react2.default.createElement(
        _IconButton2.default,
        { style: { float: 'right' }, onTouchTap: onCloseClick },
        _react2.default.createElement(_close2.default, null)
      )
    ),
    _react2.default.createElement(
      'div',
      null,
      media && _react2.default.createElement(
        _Card.CardMedia,
        { style: styles.media },
        _react2.default.createElement(_image2.default, { style: styles.img, src: media })
      ),
      _react2.default.createElement(
        _Card.CardText,
        null,
        _react2.default.createElement(_feature_table2.default, { data: data, print: print })
      )
    )
  );
};

exports.default = (0, _reactRedux.connect)(function (state, ownProps) {
  var featuresById = (0, _features_by_id2.default)(state);
  var colorIndex = (0, _color_index2.default)(state);
  var fieldMapping = (0, _field_mapping2.default)(state);
  var visibleFields = (0, _visible_fields2.default)(state);
  var fieldAnalysis = (0, _field_analysis2.default)(state);
  var id = ownProps.id || state.ui.featureId;
  var feature = featuresById[id];
  if (!feature) return {};
  var geojsonProps = feature.properties;
  var data = visibleFields.filter(function (f) {
    return typeof geojsonProps[f] !== 'undefined';
  }).map(function (f) {
    return { key: f, value: geojsonProps[f], type: fieldAnalysis[f].type };
  });
  if (feature.geometry) {
    data.unshift({
      key: 'location',
      value: feature.geometry.coordinates
    });
  }
  return {
    data: data,
    media: geojsonProps[fieldMapping.media],
    title: geojsonProps[fieldMapping.title],
    subtitle: geojsonProps[fieldMapping.subtitle],
    color: colorIndex[geojsonProps[fieldMapping.color]]
  };
})(FeatureDetail);