'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _pure = require('recompose/pure');

var _pure2 = _interopRequireDefault(_pure);

var _List = require('material-ui/List');

var _Divider = require('material-ui/Divider');

var _Divider2 = _interopRequireDefault(_Divider);

var _settings = require('material-ui/svg-icons/action/settings');

var _settings2 = _interopRequireDefault(_settings);

var _reactIntl = require('react-intl');

var _discrete_filter = require('./discrete_filter');

var _discrete_filter2 = _interopRequireDefault(_discrete_filter);

var _date_filter = require('./date_filter');

var _date_filter2 = _interopRequireDefault(_date_filter);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PropTypes = _react2.default.PropTypes;


var style = {
  outer: {
    minWidth: 300,
    maxWidth: '33%',
    overflowY: 'auto',
    zIndex: 1,
    boxShadow: 'rgba(0, 0, 0, 0.117647) 0px 1px 6px, rgba(0, 0, 0, 0.117647) 0px 1px 4px'
  },
  list: {
    paddingTop: 0
  },
  listItemInner: {
    padding: 0
  },
  listIcon: {
    fill: 'rgb(117, 117, 117)',
    left: 0,
    top: 0,
    margin: '12px',
    position: 'absolute'
  },
  link: {
    color: '#000',
    display: 'block',
    padding: '16px 16px 16px 48px',
    textDecoration: 'none'
  }
};

var messages = (0, _reactIntl.defineMessages)({
  changeFilters: {
    'id': 'filter.change',
    'defaultMessage': 'Change Filters\u2026'
  }
});

var Filter = function Filter(_ref) {
  var _ref$configureFilters = _ref.configureFilters,
      configureFilters = _ref$configureFilters === undefined ? false : _ref$configureFilters,
      _ref$filters = _ref.filters,
      filters = _ref$filters === undefined ? {} : _ref$filters,
      _ref$fieldStats = _ref.fieldStats,
      fieldStats = _ref$fieldStats === undefined ? {} : _ref$fieldStats,
      _ref$visibleFilters = _ref.visibleFilters,
      visibleFilters = _ref$visibleFilters === undefined ? [] : _ref$visibleFilters,
      location = _ref.location,
      _ref$onUpdateFilter = _ref.onUpdateFilter,
      onUpdateFilter = _ref$onUpdateFilter === undefined ? function (x) {
    return x;
  } : _ref$onUpdateFilter,
      _ref$onClickSettings = _ref.onClickSettings,
      onClickSettings = _ref$onClickSettings === undefined ? function (x) {
    return x;
  } : _ref$onClickSettings;
  return _react2.default.createElement(
    'div',
    { className: 'filter', style: style.outer },
    _react2.default.createElement(
      _List.List,
      { style: style.list },
      visibleFilters.map(function (f) {
        var field = fieldStats[f];
        var filter = filters[f];
        switch (field.filterType) {
          case _constants.FILTER_TYPES.DISCRETE:
            return _react2.default.createElement(
              'div',
              { key: f },
              _react2.default.createElement(_discrete_filter2.default, {
                fieldName: f,
                checked: filter ? filter.in : (0, _keys2.default)(field.values),
                values: field.values,
                onUpdate: onUpdateFilter }),
              _react2.default.createElement(_Divider2.default, null)
            );
          case _constants.FILTER_TYPES.RANGE:
            return;
          case _constants.FILTER_TYPES.DATE:
            return _react2.default.createElement(
              'div',
              { key: f },
              _react2.default.createElement(_date_filter2.default, {
                fieldName: f,
                filter: filter,
                min: filter ? filter['>='] : field.valueStats.min,
                max: filter ? filter['<='] : field.valueStats.max,
                valueMin: field.valueStats.min,
                valueMax: field.valueStats.max,
                onUpdate: onUpdateFilter }),
              _react2.default.createElement(_Divider2.default, null)
            );
        }
      }),
      _react2.default.createElement(
        _List.ListItem,
        { innerDivStyle: style.listItemInner },
        _react2.default.createElement(
          'a',
          { style: style.link, onClick: onClickSettings },
          _react2.default.createElement(_reactIntl.FormattedMessage, messages.changeFilters),
          ' ',
          _react2.default.createElement(_settings2.default, { style: style.listIcon })
        )
      )
    )
  );
};

Filter.propTypes = {
  configureFilters: PropTypes.bool,
  filters: PropTypes.object,
  fieldStats: PropTypes.object.isRequired,
  visibleFilters: PropTypes.arrayOf(PropTypes.string).isRequired,
  /* called with valid mapbox-gl filter when updated */
  onUpdateFilter: PropTypes.func,
  onClickSettings: PropTypes.func
};

exports.default = (0, _pure2.default)(Filter);