'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _reselect = require('reselect');

var _field_analysis = require('./field_analysis');

var _field_analysis2 = _interopRequireDefault(_field_analysis);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function count(o) {
  return (0, _keys2.default)(o).length;
}

function getFeatureCount(state) {
  return state.features.count;
}

var createCompareFn = function createCompareFn(featureCount) {
  return function (a, b) {
    // If either field appears in less than 80% of features,
    // prefer the field that appears in more features
    var countThreshold = featureCount * 0.8;
    if (a.count < countThreshold || b.count < countThreshold) {
      return b.count - a.count;
    }

    // If one of the values is between 5 & 10, and the other isn't,
    // prefer the one that is.
    var aCountGood = count(a.values) >= 5; // && count(a.values) <= 10
    var bCountGood = count(b.values) >= 5; // && count(b.values) <= 10
    if (aCountGood && !bCountGood) return -1;
    if (bCountGood && !aCountGood) return 1;

    // Prefer fields with the least number of words
    return a.wordStats.mean - b.wordStats.mean;
  };
};

/**
 * Return a sorted list of the best fields to use for a filter
 */
var getBestFilterFields = (0, _reselect.createSelector)(_field_analysis2.default, getFeatureCount, function (fieldAnalysis, featureCount) {
  var compareFn = createCompareFn(featureCount);
  var discreteFields = (0, _keys2.default)(fieldAnalysis).map(function (fieldname) {
    return fieldAnalysis[fieldname];
  }).filter(function (field) {
    return field.filterType === _constants.FILTER_TYPES.DISCRETE;
  });
  return discreteFields.sort(compareFn);
});

exports.default = getBestFilterFields;