'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reselect = require('reselect');

var _best_fields = require('./best_fields');

var _best_fields2 = _interopRequireDefault(_best_fields);

var _field_analysis = require('./field_analysis');

var _field_analysis2 = _interopRequireDefault(_field_analysis);

var _colored_field = require('./colored_field');

var _colored_field2 = _interopRequireDefault(_colored_field);

var _date_field = require('./date_field');

var _date_field2 = _interopRequireDefault(_date_field);

var _id_fields = require('./id_fields');

var _id_fields2 = _interopRequireDefault(_id_fields);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getTitleFieldName = (0, _reselect.createSelector)(_best_fields2.default, _date_field2.default, _id_fields2.default, function (bestFilterFields, dateFieldName, idFieldNames) {
  return bestFilterFields[0] && bestFilterFields[0].fieldname || dateFieldName || idFieldNames[0] || 'No Title';
});

var getSubtitleFieldName = function getSubtitleFieldName(state) {
  var bestFilterFields = (0, _best_fields2.default)(state);
  return bestFilterFields[1] && bestFilterFields[1].fieldname;
};

var getMediaFieldName = (0, _reselect.createSelector)(_field_analysis2.default, function (fieldAnalysis) {
  var mediaField = void 0;
  for (var fieldname in fieldAnalysis) {
    var field = fieldAnalysis[fieldname];
    if (field.type !== _constants.FIELD_TYPES.IMAGE && field.type !== _constants.FIELD_TYPES.VIDEO) continue;
    if (!mediaField) {
      mediaField = field;
      continue;
    }
    var imageVsVideo = field.type === _constants.FIELD_TYPES.IMAGE && mediaField.type === _constants.FIELD_TYPES.VIDEO;
    var higherCount = field.type === mediaField.type && field.count > mediaField.count;
    if (imageVsVideo || higherCount) {
      mediaField = field;
    }
  }
  return mediaField && mediaField.fieldname;
});

var getFieldMapping = (0, _reselect.createSelector)(function (state) {
  return state.fieldMapping;
}, getTitleFieldName, getSubtitleFieldName, getMediaFieldName, _colored_field2.default, function (fieldMapping, titleFieldName, subtitleFieldName, mediaFieldName, coloredFieldName) {
  return {
    title: fieldMapping.title || titleFieldName,
    subtitle: fieldMapping.subtitle || subtitleFieldName,
    media: fieldMapping.media || mediaFieldName,
    color: fieldMapping.color || coloredFieldName
  };
});

exports.default = getFieldMapping;