'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filters = exports.features = exports.mapboxFilter = exports.fieldMapping = exports.mapViewFeature = undefined;

var _react = require('react');

// GeoJSON passed to the map view must be a FeatureCollection
// of point features with specific properties used for the popup
// and marker coloring.
// We need to ensure each feature has an id so we can handle
// callbacks for when a marker is clicked or hovered.
var mapViewFeature = exports.mapViewFeature = _react.PropTypes.shape({
  id: _react.PropTypes.oneOfType([_react.PropTypes.string, _react.PropTypes.number]).isRequired,
  type: _react.PropTypes.oneOf(['Feature']),
  geometry: _react.PropTypes.oneOfType([_react.PropTypes.oneOf([null]), _react.PropTypes.shape({
    type: _react.PropTypes.oneOf(['Point']).isRequired,
    coordinates: _react.PropTypes.array.isRequired
  })]).isRequired,
  properties: _react.PropTypes.shape({
    __mf_color: _react.PropTypes.string.isRequired,
    __mf_id: _react.PropTypes.oneOfType([_react.PropTypes.string, _react.PropTypes.number]).isRequired
  }).isRequired
});

var fieldMapping = exports.fieldMapping = _react.PropTypes.shape({
  media: _react.PropTypes.string,
  mediaType: _react.PropTypes.string,
  title: _react.PropTypes.string.isRequired,
  subtitle: _react.PropTypes.string
});

/* See https://www.mapbox.com/mapbox-gl-style-spec/#types-filter */
/* We only support a specific subset of the mapbox array spec */
var mapboxFilter = exports.mapboxFilter = _react.PropTypes.arrayOf(_react.PropTypes.oneOfType([_react.PropTypes.oneOf(['all']), _react.PropTypes.arrayOf(_react.PropTypes.string)]));

var features = exports.features = _react.PropTypes.arrayOf(_react.PropTypes.shape({
  type: _react.PropTypes.oneOf(['Feature']).isRequired,
  geometry: _react.PropTypes.oneOfType([_react.PropTypes.oneOf([null]), _react.PropTypes.shape({
    type: _react.PropTypes.oneOf(['Point']).isRequired,
    coordinates: _react.PropTypes.array.isRequired
  })]).isRequired,
  properties: _react.PropTypes.object
})).isRequired;

/**
 * Our filter structure is similar to mapbox filters but we index
 * by key and then expression. We only allow filters to combined
 * with logical AND using the "all" expression.
 * @example
 * ```
 * var filter = {
 *   name: {
 *     'in': ['bob', 'susan']
 *   },
 *   age: {
 *     '<=': 50,
 *     '>=': 30
 *   }
 * }
 */
var filters = exports.filters = _react.PropTypes.objectOf(_react.PropTypes.objectOf(_react.PropTypes.arrayOf(_react.PropTypes.string)));